(*
  Copyright 2010 Gerd Stolpmann

  This file is part of Plasma, a distributed filesystem and a
  map/reduce computation framework. Unless you have a written license
  agreement with the copyright holder (Gerd Stolpmann), the following
  terms apply:

  Plasma is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Plasma is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Foobar.  If not, see <http://www.gnu.org/licenses/>.

*)
(* $Id: mapred_config.mli 282 2010-10-28 00:13:50Z gerd $ *)

(** Configuration of mapred servers *)

class type mapred_config =
object
  method nn_clustername : string
    (** The clustername *)
  method nn_nodes : string list
    (** The name nodes in "host:port" syntax *)
  method mr_task_nodes : string list
    (** Task nodes (only hostname) *)
  method mr_task_port : int
    (** The port number *)
  method mr_task_tmpdir : string
    (** A directory where to put executables, logs, etc. *)
  method mr_task_load_limit : float
    (** Load limit per task server (in number of tasks). Should be set to
	a small multiple of the number of cores.
     *)
  method mr_shm_low : int64
    (** Low watermark for shared memory. If shm consumption drops below this
	value shm is no longer considered as scarce resource. Good value:
	1/4 of available shm (usually 1/8 of total RAM)
     *)
  method mr_shm_high : int64
    (** High watermark for shared memory. If shm consumption is above this
	value shm is considered as scarce resource. Good value:
	3/4 of available shm (usually 3/8 of total RAM)
     *)
  method mr_buffer_size : int
    (** The normal size of I/O buffers. E.g. 64M *)
  method mr_buffer_size_tight : int
    (** The size of I/O buffers when RAM is tight. E.g. 16M *)
  method mr_sort_size : int
    (** The size of the buffers for sorting. E.g. 128M *)
end


val extract_config : Netplex_types.config_file -> mapred_config
  (** Config section must look like:

      {[
         netplex {
           ...
           namenodes {
             clustername = "cluster1";
             node { addr = "hostname:port" }
             node { addr = "hostname:port" }
             ...
           }
           mapred {
             node { addr = "hostname" }
             node { addr = "hostname" }
             ...
             port = 1234;
             tmpdir = "/somewhere";
             load_limit = 8.1;
           }
        }
      ]}
   *)


val executable_version : unit -> string
  (** Returns an MD5 sum of the running executable *)
